@@ -14,7 +14,7 @@ details   AD9912 development board is configurable by USB through an USB
 import logging
 from array import array
 import usb.core
-from fx2_m import Fx2Core
+from iopy.fx2 import Fx2Core
 
 
 AD_VENDOR_ID = 0x0456
